<?php
/*
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

require_once('inc/config.php');
require_once('inc/security.php');
require_once('inc/functions.php');
require_once('inc/output.php');
require_once('inc/db.php');
require_once('inc/user.php');
require_once('inc/cat.php');
require_once('inc/feed.php');

require_once('magpierss/rss_fetch.inc');

$DEBUG = 0;
if ($DEBUG) error_reporting(E_ALL);

// We won't allow any access to this page with the proper authorization
//
if (($UID = getUidFromCookie()) != NULL) {
  $db = new DB();
  $db->open() or die ("Unable to connect to database.");

  $user = new user ($db, $UID);
  if (!$user->valid) die ("Bad User.");

  outputHeader ($user, 'Add/Edit feed');
  outputNavigation ($db, $user,
    (isset($_GET['category']) ? intval($_GET['category']) : 0));

  echo '<div id="wrapper"><div id="content"><div class="category">';

  //-----------------------------------------------------------------------
  // Show form for adding NEW src
  //
  if (isset($_GET['new'])) {
?>

<form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="POST" name="account_prefs">
  <fieldset>
    <legend>Add a new feed</legend>

    <fieldset>
      <legend>Enter the category:</legend>

<?php
    $selCat = isset($_GET['category']) ? intval($_GET['category']) : -1;
?>
      <input type="radio" name="select_category" value="1" <?php echo ($selCat==-1) ? '' : 'checked' ?> /> Use existing Category: 
      <select name="existing_category">
        <option value="" />-no category selected-</option>
<?php
    foreach (category::all($db, $user->userid, 'ORDER BY name') as $cat) {
      echo '<option '. (($selCat == $cat->id) ? 'selected="1" ' : '')  .' value="' . $cat->id . '">'. htmlspecialchars($cat->name, ENT_NOQUOTES) .'</option>';
    }
?>
      </select><br />

      <input type="radio" name="select_category" value="2" <?php echo ($selCat==-1) ? 'checked' : '' ?> />
      Create new Category:
      <input type="text" name="new_category" size="30" maxlength="255" />
    </fieldset>

    <p>Enter the title of the source:<br />
    <input type="Text" name="source_title" size="40" maxlength="255"></p>

    <p>Enter a link to the site's main page:<br />
    <input type="Text" name="main_link" size="55" maxlength="255"></p>

    <p>Enter a link to the RSS feed:<br />
    <input type="Text" name="rss_link"  size="55" maxlength="400">&nbsp;<i>(required)</i></p>

    <p>Enter a link to an image for the site:<br />
    <input type="Text" name="image_url"  size="55" maxlength="255"></p>

    <p>Enter number of headlines to show:<br />
    <input type="Text" name="num_headlines"  size="5" maxlength="255" value="<?php echo $user->headlines ?>"></p>

    <p><input type="Submit" name="newSubmit" value="Enter new source"></p>
  </fieldset>
</form>

<?php
  //-----------------------------------------------------------------------
  // Incoming POST with new source info
  //
  } elseif (isset($_POST['newSubmit'])) {

    // process form
    if (!$_POST['rss_link']) {

      echo '<p>Sorry! You have to at least fill in the RSS feed link. Please <a href="'. $_SERVER['PHP_SELF'] .'?new=y">try again</a>.</p>';

    } elseif (!($rss = fetch_rss($_POST['rss_link']))) {

      echo '<p>Sorry! That link didn\'t work out. Please <a href="'. $_SERVER['PHP_SELF'] .'?new=y">try another one</a>.</p>';

    } else {

      if (!$_POST['source_title'])
        $_POST['source_title'] = $rss->channel['title'];
      if (!$_POST['main_link'])
        $_POST['main_link'] = $rss->channel['link'];

      if ($_POST['source_title'] && $_POST['main_link']) {

        if ($_POST['select_category'] == 1) {
          $cat = new category ($db, intval($_POST['existing_category']), $user->userid);
        } else {
          // Create the new category and use its ID
          $cat = new category();
          $cat->name = $_POST['new_category'];
          if (!$cat->insert ($db, $user->userid)) {
            echo '<p>There has been an error creating the category: '. $db->error() .'</p>';
            unset($cat);
          }
        }

        if (isset($cat) && $cat->valid) {
          $feed = new feed();
          $feed->name = $_POST['source_title'];
          $feed->main_link = $_POST['main_link'];
          $feed->rss_link = $_POST['rss_link'];
          $feed->image_link = $_POST['image_url'];
          $feed->cat_id = $cat->id;
          $feed->headlines = $_POST['num_headlines'];
          
          if ($feed->insert ($db, $user->userid)) {

            echo '<p>Added feed: <a href="index.php?more='. $feed->id .'">'. htmlspecialchars($feed->name) .'</a> in category <a href="index.php?category='. $feed->cat_id .'">'. htmlspecialchars($cat->name) .'</a>.</p>';
            echo '<p><a href="'. $_SERVER['PHP_SELF'] .'?edit='. $feed->id .'">Edit the new feed\'s information.</p>';

          } else {
            echo '<p>There has been an error creating the feed: '. $db->error() .'</p>';
          }

        } else {
          if ($DEBUG) { echo mysql_error(); }
          echo "<p>There has been an error - please try again!</p>";
        }

      } else {
        echo '<p>Sorry, couldn\'t figure out the title or main link.</p>';
      }  
    }

  //-----------------------------------------------------------------------
  // Show form for editing existing category
  //
  } elseif (isset($_GET['editCat'])) {
    $cat = new category ($db, intval($_GET['editCat']), $user->userid);
    if (!$cat->valid) { return; }
?>

<form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="POST" name="account_prefs">

<fieldset>
<legend>Edit category</legend>

Enter new category name:<br />
<input type="text" name="categoryName" size="30" maxlength="255" value="<?php echo htmlspecialchars($cat->name)?>"><br /><br />

<input type="hidden" name="change_id" value="<?php echo $cat->id ?>">
<input type="Submit" name="editCatSubmit" value="Make Changes">
</form>
</fieldset>

<?php
  //-----------------------------------------------------------------------
  // Show form for editing existing category
  //
  } elseif (isset($_REQUEST['editCatSubmit'])) {
    $cat = new category ($db, intval($_REQUEST['change_id']), $user->userid);
    if (!$cat->valid) { return; }

    $cat->name = $_REQUEST['categoryName'];
    if ($cat->update($db, $user->userid)) {
      echo '<p>Category <a href="index.php?category='. $cat->id .'">'. $cat->name .'</a> updated.</p>';
    } else {
      echo '<p>Edit failed, try again.</p>';
    }

  //-----------------------------------------------------------------------
  // Show form for editing existing feed
  //
  } elseif (isset($_GET['edit'])) {

    $feed = new feed($db, intval($_GET['edit']), $user->userid);
    if (!$feed->valid) { return; }
?>

<form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="POST">

<fieldset>
<legend>Edit feed <?php echo htmlspecialchars($feed->name, ENT_NOQUOTES)?></legend>

<fieldset>
<legend>Enter the category:</legend>
<input type="radio" name="select_category" value="1" checked>
Use existing Category: 
<select name="existing_category">

<?php
    foreach (category::all($db, $user->userid, 'ORDER BY name') as $cat) {
      echo '<option '. (($feed->cat_id == $cat->id) ? 'selected="1" ' : '')  .' value="' . $cat->id . '" />' . htmlspecialchars($cat->name, ENT_NOQUOTES) .'<br />';
    }
?>

</select><br />

<input type="radio" name="select_category" value="2">
Create new Category:
<input type="text" name="new_category" size="30" maxlength="255">
</fieldset><br />


Enter the title of the source:<br />
<input type="Text" name="source_title" size="40" maxlength="255" value="<?php echo htmlspecialchars($feed->name)?>"><br /><br />

Enter a link for the main page:<br />
<input type="Text" name="main_link" size="55" maxlength="255" value="<?php echo htmlspecialchars($feed->main_link)?>"><br /><br />

Enter the rss source:<br />
<input type="Text" name="rss_link"  size="55" maxlength="255" value="<?php echo htmlspecialchars($feed->rss_link)?>"><br /><br />

Enter a link to an image for the site:<br />
<input type="Text" name="image_url"  size="55" maxlength="255" value="<?php echo htmlspecialchars($feed->image_link)?>"><br /><br />

Enter number of headlines to show:<br />
<input type="Text" name="num_headlines"  size="5" maxlength="5" value="<?php echo $feed->headlines?>"><br /><br />

<input type="hidden" name="change_id" value="<?php echo $feed->id ?>">
<input type="Submit" name="editSubmit" value="Make Changes">
</form>
</fieldset>

<?php
  //-----------------------------------------------------------------------
  // Incoming POST with edited information
  //
  } elseif (isset($_POST['editSubmit'])) {

    if (!$_POST['source_title'] || !$_POST['main_link'] || !$_POST['rss_link']) {

      echo "<p>Sorry! You didn\'t fill in all the fields! please go back and try again.</p>";
    
    } elseif ( !fetch_rss( $_POST['rss_link'] )) {

      echo "<p>You must enter a valid RSS source - please go back and try again.</p>";

    } else {

      if ($_POST['select_category'] == 1) {
        $cat = new category ($db, intval($_POST['existing_category']), $user->userid);
      } else {
        // Create the new category and use its ID
        $cat = new category();
        $cat->name = $_POST['new_category'];
        if (!$cat->insert ($db, $user->userid)) {
          echo '<p>There has been an error creating the category: '. $db->error() .'</p>';
          unset($cat);
        }
      }

      if (isset($cat) && $cat->valid) {
        $feed = new feed($db, intval($_POST['change_id']), $user->userid);

        if ($feed->valid) {

          $feed->name = $_POST['source_title'];
          $feed->main_link = $_POST['main_link'];
          $feed->rss_link = $_POST['rss_link'];
          $feed->image_link = $_POST['image_url'];
          $feed->cat_id = $cat->id;
          $feed->headlines = $_POST['num_headlines'];

          if ($feed->update ($db, $user->userid)) {
            echo '<p>Changes made to feed: <a href="index.php?more='. $feed->id .'">'. htmlspecialchars($feed->name) .'</a> in category <a href="index.php?category='. $feed->cat_id .'">'. htmlspecialchars($cat->name) .'</a>.</p>';
            echo '<p>You may <a href="'. $_SERVER['PHP_SELF'] .'?edit='. $feed->id .'">edit the feed\'s information.</p>';
          } else {
            echo '<p>There has been a problem entering your changes: '. $db->error() .'</p>';
          }
        } else {
          echo '<p>There has been an error (bad feed) - please try again!</p>';
        }
      } else {
        echo '<p>There has been an error - please try again!</p>';
      }
    }
  //-----------------------------------------------------------------------
  } else {
    // no action specified
    echo "<p>What was it you wanted to do?</p>";
  }

  // Print header with categories
  //outputNavigation($db, $user);

  echo '</div></div></div>';

} else {  // if auth
  redirectToLogin();
}

include('foot.php');
?>
