<?php
/*
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


require_once('inc/config.php');
require_once('inc/security.php');
require_once('inc/functions.php');
require_once('inc/output.php');
require_once('inc/db.php');
require_once('inc/user.php');
require_once('inc/cat.php');
require_once('inc/feed.php');


$DEBUG = 0;

// We won't allow any access to this page with the proper authorization
//
if (($UID = getUidFromCookie()) != NULL) {

  $db = new DB();
  $db->open() or die ("Unable to connect to database.");
  $user = new user ($db, $UID);
  if (!$user->valid) die ("Bad User.");

  outputHeader ($user, 'Preferences');
	outputNavigation ($db, $user);
  echo '<div id="wrapper"><div id="content">';
  echo checkInsecureFilePerms();
  echo '<div class="category">';

  //----------------------------------------------------------------
  // Form: delete a feed
  //
	if (isset($_GET['delete'])) {
?>
<form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="POST" name="delete_menu">
  <fieldset>
  <legend>Delete Feed</legend>

    <p>Please select the feed to delete:</p>

    <select name="delete_feed">
    <option value="">-no source selected-</option>

<?php
    foreach (feed::all ($db, $user->userid) as $feed)
      echo '<option value="'. $feed->id .'">'. htmlspecialchars($feed->name) .'</option>';
?>

    </select>

    <p><input type="Submit" name="delete_source_button" value="Delete source"></p>
  </fieldset>
</form>

<?php
  //----------------------------------------------------------------
  // Form: delete feed confirm
  //
  } elseif (isset($_REQUEST['delete_feed'])) {

    $delete_source = intval($_REQUEST['delete_feed']);
    $feed = new feed ($db, $delete_source, $user->userid);
    if (!$feed->valid) { die ("Bad feed"); }

?>

<p>Do you really mean to delete <?php echo $feed->name ?>?</p>

<form method="post" action="<?php echo $_SERVER['PHP_SELF'] ?>">
  <input type="hidden" name="kill_id" value="<?php echo $delete_source ?>">
  <input type="Submit" name="delete_feed_confirm" value="yeah, go for it">
</form>

<?php
  //----------------------------------------------------------------
  // Action: delete feed
  //
	} elseif (isset($_POST['delete_feed_confirm'])) {

		if ($DEBUG) { echo "killing " . $_POST['kill_id']; }

    // XXX move SQL into feed and feedlink classes
		$sql = 'DELETE FROM '. DB_PREFIX.$user->userid .'_feeds WHERE id=\''. intval($_POST['kill_id']) .'\'';
		$sql2 = 'DELETE FROM '. DB_PREFIX ."links WHERE src_id='". $user->userid . intval($_POST['kill_id']) . "'";

		if ($db->query($sql)) {
			echo "<p>feed deleted!</p>";
			if ($db->query($sql2)) {
				echo "<p>old links deleted!</p>";
			}
      echo '<p>Back to <a href="index.php?category='. $user->default_cat .'">your default category</a>.</p>';
		}

  //----------------------------------------------------------------
  // Form: delete a category
  //
	} elseif (isset($_GET['deleteCat'])) {
?>

<form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="POST" name="delete_menu">
  <fieldset>
    <legend>Delete a category</legend>

    Select the category:
    <select name="deleteCatId">
      <option value="">-no category selected-</option>
<?php
    foreach (category::all($db, $user->userid, 'ORDER BY name') as $cat) {
      // Check that no feeds are assigned to this cat
      if (count(feed::all($db, $user->userid, "WHERE cat_id='$cat->id'")) == 0)
        echo '<option value="'. $cat->id .'">'. htmlspecialchars($cat->name) ."</option>\n";
		}
?>
    </select>
    <p><i>Note that only categories with no feeds in them are listed.</i></p>
    <p><input type="Submit" name="delete_source_button" value="Delete category"></p>
  </fieldset>
</form>

<?php
  //----------------------------------------------------------------
  // Action: delete a category
  //
	} elseif (isset($_POST['deleteCatId'])) {

    if (intval($_POST['deleteCatId'])) {
      // XXX move SQL to category class
      $sql = 'DELETE FROM '. DB_PREFIX.$user->userid .'_cat WHERE id=\''. intval($_POST['deleteCatId']) .'\'';

      if ($db->query($sql)) {
        echo '<p>Category deleted!</p>';
        echo '<p>Back to <a href="index.php?category='. $user->default_cat .'">your default category</a>.</p>';
      } else {
        echo '<p>something went wrong; please try again?.</p>';
      }
    } else {
      echo '<p>nothing to delete</p>';
    }

  //----------------------------------------------------------------
  // Action: purge old links
  //
	} elseif (isset($_GET['purge'])) {

    // XXX move SQL to feedlink class
		$sql = 'DELETE FROM '. DB_PREFIX ."links WHERE src_id REGEXP '". $user->userid ."[0-9]*' AND DATE_SUB(CURDATE(), INTERVAL 90 DAY) >= pubdate";

		if ($db->query($sql)) {
			echo '<p>Purged article links!</p>';
		} else {
			echo '<p>Something went wrong; please try again?.</p>';
		}

  //----------------------------------------------------------------
  // Action: change user prefs
  //
	} elseif (isset($_POST['change_prefs'])) {

    $user->name = $_POST['username'];
    $user->timeout = $_POST['timeout_select'];
    $user->headlines = $_POST['number_headlines_select'];
    $user->show_images = array_key_exists('showImages', $_POST);
    if (!empty($_POST['default_category']))
      $user->default_cat = $_POST['default_category'];
    $user->max_links = $_POST['maxLinks'];

    if ($user->update ($db)) {
			echo '<p>Preferences updated!</p>';
		} else {
			echo '<p>There has been a problem updating your preferences, please go back and try again.</p>';
		}

  //---------------------------------------------------------------------
  // Form: change user prefs
  //
	} else {
?>

<form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="POST">
<fieldset>
<legend>Change User Preferences</legend>

<p>Name:
<input type="text" name="username" size="20" maxlength="64" value="<?php echo htmlspecialchars($user->name) ?>" /></p>

<p>Timeout before re-checking rss sources (in minutes):
<select name="timeout_select">
	<option selected value="<?php echo $user->timeout; ?>"><?php echo ($user->timeout / 60); ?></option>
	<option value="600">10</option>
	<option value="900">15</option>
	<option value="1200">20</option>
	<option value="1500">25</option>
	<option value="1800">30</option>
	<option value="3600">60</option>
</select></p>

<p>Default number of headlines to show for new sources:
<select name="number_headlines_select">
	<option selected><?php echo $user->headlines; ?></option>
	<option>5</option>
	<option>10</option>
	<option>15</option>
	<option>20</option>
</select></p>

<p>Display site images? 
<input type="checkbox" name="showImages" <?php echo ($user->show_images ? 'checked="true"' : '') ?> /> Yes</p>

<p>Default category to display:
<select name="default_category">
<option value="0">All Sources
<?php
    foreach (category::all($db, $user->userid, 'ORDER BY name') as $cat) {
      echo '<option '. (($user->default_cat == $cat->id) ? 'selected="1" ' : '')  .' value="' . $cat->id . '" />'. htmlspecialchars($cat->name) ."\n";
    }
?>
</select></p>

<p>Maximum number of headlines to show on single feed screen (0 for no restriction):
<input type="text" name="maxLinks" size="5" maxlength="10" value="<?php echo $user->max_links ?>" /></p>

<p><input type="Submit" name="change_prefs" value="Make Changes" /></p>
</fieldset>
</form>

<p>Other options:</p>
<ul>
<li><a href="add.php?new=y">Add a new source</a></li>
<li><a href="<?php echo $_SERVER['PHP_SELF'] ?>?delete=y" >Delete a feed</a></li>
<li><a href="<?php echo $_SERVER['PHP_SELF'] ?>?deleteCat=y" >Delete a category</a></li>
<li><a href="auth.php?pwchange=1">Change password</a></li>
<li><a href="<?php echo $_SERVER['PHP_SELF'] ?>?purge=1">purge articles older than 90 days</a> (if they are still in the feed, they will reappear)</li>
<li><a href="export.php">Import or Export feeds to OPML</a></li>
</ul>

<?php
	}

  echo '</div></div></div>';

} else {	// if auth
  redirectToLogin();
}

include('foot.php');
?>
